@@ -935,7 +935,7 @@ class RepeatedFunction:
         self.is_running = False
 
 class NumerousAdminClient(NumerousClient):
-    def __init__(self, token=None):
+    def __init__(self, token=None, server=None, port=None):
 
         self._token = get_env(token, 'NUMEROUS_API_TOKEN')
 
@@ -948,7 +948,7 @@ class NumerousAdminClient(NumerousClient):
         self._base_client = stub
         self._terminated = False
 
-        log.info('init client')
+        log.info('init admin client')
 
 @contextmanager
 def open_admin_client() -> NumerousAdminClient:
